@@ -4,6 +4,8 @@ import os
 
 from django.core.management.base import BaseCommand
 
+from optparse import make_option
+
 from proxylist.models import Proxy
 
 
@@ -11,6 +13,21 @@ class Command(BaseCommand):
     args = '<hidemyass proxy list files>'
     help = 'Update proxy list from file(s)'
 
+    option_list = BaseCommand.option_list + (
+        make_option(
+            '--type',
+            dest='type',
+            default='http',
+            help='http, https, socks4, socks5'),
+    )
+
+    def get_data(self, line):
+        line = line.strip()
+        if '@' in line:
+            proxy, auth = line.split('@', 2)
+            return proxy.split(':') + auth.split(':')
+        return line.split(':', 2) + ['', '']
+
     def handle(self, *args, **options):
         for filename in args:
             if not os.path.isfile(filename):
@@ -21,13 +38,7 @@ class Command(BaseCommand):
 
             with open(filename, 'r') as f:
                 for proxy in f:
-                    proxy = proxy.replace('\n', '').replace('\r', '')
-
-                    try:
-                        ip_address, port = proxy.split(':', 2)
-                    except ValueError:
-                        self.stderr.write("Invalid format %s. ip:port" % proxy)
-                        continue
+                    hostname, port, user, password = self.get_data(proxy)
 
                     try:
                         port = int(port)
@@ -36,4 +47,6 @@ class Command(BaseCommand):
                         continue
 
                     Proxy.objects.get_or_create(
-                        ip_address=ip_address, port=port)
+                        hostname=hostname, port=port,
+                        user=user, password=password,
+                        proxy_type=options['type'])
